| combinatorics | R Documentation |
permutation computes the number of permutations
variation computes the number of variations with and without replication
combination computes the number of combinatios with and without replication
combinatorics computes all combinatorics results for k<n and returns it as list:
permutation.nP(n)
permutation.kP(k)
permutation.nkP(n; k)
variationV(n;k)
variation.repV^W(n;k)
combinationK(n;k)
combination.repK^W(n;k)
combinatorics(n, k)
variation(n, k, repl = FALSE)
combination(n, k, repl = FALSE)
permutation(n, k = rep(1, n))
lfact(n)
lfactquot(n, ...)
lbinom(n, k)
n |
numeric: total number of elements |
k |
numeric: number of elements to choose |
repl |
logical: with reptition (default: |
... |
numeric: further arguments to |
a list
permutation(8)
permutation(8, c(1,3,2,2))
combination(8, 4)
combination(8, 4, TRUE)
variation(8, 4)
variation(8, 4, TRUE)
combinatorics(8, 4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.