all_different: all_different

View source: R/all_different.R

all_differentR Documentation

all_different

Description

Test if the differences between the entries in obj is larger than tol.

Usage

all_different(obj, tol)

Arguments

obj

object: numeric R object which can be converted to a vector

tol

numeric: minimum value

Value

logical

Examples

x <- runif(10)
all_different(x, 0.0001)
all_different(x, 1)

sigbertklinke/exams2moodle documentation built on July 6, 2023, 3:26 p.m.