| binom_param | R Documentation |
binom_param
binom_param(n, p, mean = NA, sd = NA, norm = NA, pois = NA)
n |
integer: number of observations |
p |
numeric: vector of probabilities |
mean |
integer: number of digits the mean should have |
sd |
integer: number of digits the standard deviation should have |
norm |
logical: normal approximation possible |
pois |
logical: poisson approximation possible |
a data frame with possible choices of n , p, mean and sd
binom_param(1000:50000, (5:25)/100, 0, 0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.