| histdata | R Documentation |
Returns data for a histogram, calls internally hist(..., plot=FALSE).
mean returns the mean of the data
quantile and median return the quantile(s) or median with an attribute pos, the class number of the qauntile(s) or the median.
histdata(x, breaks = "Sturges", probs = seq(0, 1, 0.25), ...)
## S3 method for class 'histogram'
quantile(x, probs = seq(0, 1, 0.25), ...)
## S3 method for class 'histogram'
median(x, ...)
## S3 method for class 'histogram'
mean(x, ...)
x |
numeric data or histogram data |
breaks |
one of:
In the last three cases the number is a suggestion only; as the
breakpoints will be set to |
probs |
numeric: probabilities to use if |
... |
further parameter used in graphics::hist |
like in graphics::hist with the additional list elements
lower lower class borders,
upper upper class borders,
width class widths,
relfreq the relative class frequency,
cumfbrk the cumulated relative frequency at the breaks,
maxdens the indices of the maximal density values,
maxcount the indices of the maximal count values
x the original finite data, and
class the class number for each value in x.
#1
x <- seq(0, 1, by=0.25)
print(hist(x, plot=FALSE))
histdata(x)
#2
x <- seq(0, 1, by=0.25)
print(hist(x, x, plot=FALSE))
histdata(x, x)
#3
print(hist(x, x, right=FALSE, plot=FALSE))
histdata(x, x, right=FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.