| lsumprod | R Documentation |
lsumprod creates a latex printout of \sum_i x_i y_i with brackets if x_i or y_i starts with a -.
lsum creates a latex printout of x as sum.
lprod creates a latex printout of x as product.
lmean creates a latex printout as \frac{x_1+...+x_n}{n}.
lvar creates a latex printout as \frac{(x_1-xbar)^2+...+(x_n-xbar)^2}{n}.
lbr creates a latex printout of x with brackets if x starts with a -.
lsgn creates a latex printout of x with a plus or minus at the beginning.
lsumprod(..., br = "(")
lsum(x)
lprod(x)
lmean(x)
lvar(x, mu = NULL, br = "(")
lbr(x, br = c("(", "[", "{", "|", "||", "<", "a", "c", "f"), subset = NULL)
lsgn(x)
... |
further input values |
br |
character: which brackets to use, either
|
x |
numeric: input values |
mu |
numeric: population mean (default: |
subset |
logical: indicates to which elements brackets are added (default: |
character
lsumprod(-2:2, (1:5)/10)
lbr(-2:2)
lsum(-2:2)
lmean(-2:2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.