| sqrtnp | R Documentation |
Computes sqrt(n*p*(1-p)) for all combinations of n and p.
If the result has only digits after the decimal point then these n, p,
and sqrt(n*p*(1-p)) is returned in a data frame.
sqrtnp(n, p, digits = 2, tol = 10^(-digits - 4))
n |
numeric: vector of observations numbers |
p |
numeric: vector of probabilities |
digits |
numeric: number of digits to check (default: |
tol |
numeric: tolerance (default: |
If abs(v-round(v, digits))<tol then a number v is consired as a number
with only digits after the decimal point.
a data frame with the columns n, p, np (=np) and snp (=sqrt(np(1-p)))
n <- 30:250
p <- (10:40)/100
sqrtnp(n, p)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.