View source: R/all_different.R
| all_different | R Documentation |
Test if the differences between the entries in obj is larger than tol.
all_different(obj, tol)
obj |
object: numeric R object which can be converted to a vector |
tol |
numeric: minimum value |
logical
x <- runif(10)
all_different(x, 0.0001)
all_different(x, 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.