| breaks | R Documentation |
Creates a number of equidistant or non-equidistant breaks for given data x.
If width is not given then it will be set to diff(pretty(x))[1].
probs can either be a single integer giving the number of quantiles or a vector of probabilities with values in [0,1].
Note that if width is too large then using probs may result in equidistant breaks, too.
breaks(x, width = NULL, probs = NULL)
x |
numeric: data |
width |
numeric: class width (default: |
probs |
numeric: number of non-equidistant classes (default: |
a numeric vector of breaks
x <- rnorm(100, mean=1.8, sd=0.1)
breaks(x)
breaks(x, 0.1)
breaks(x, 0.1, probs=4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.