| is.prob | R Documentation |
Checks if x is in an opened/closed interval between min and max.
The defaults are choosen such that the interval is an the interval (0,1), for example if x is a probability.
is.prob(x, open = TRUE, min = 0, max = 1)
x |
numeric: values to check |
open |
logical(1): are the left and right borders are open or closed (default: |
min |
numeric: minimal value (default: |
max |
numeric: maximal value (default: |
a logical vector with the same length as x
is.prob(runif(1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.