| now | R Documentation |
Returns a time stamp based on the current time. now calls basically
gsub('.', '', sprintf('%.20f', as.numeric(Sys.time())), fixed=TRUE).
To ensure that at each call a different time stamp is delivered now
may call gsub(...) several times until two different results are delivered.
The last one is then returned.
now(last = 35)
last |
integer: how many digits should be returned (default: |
a character
now() # returns all digits
now(3) # returns only the first three digits
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.